/****************************************
Replication do-file for: Supplement Table 1
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/households.dta", clear
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.age_]/_se[c.treatment#c.age_]) (_b[c.treatment#c.any_education]/_se[c.treatment#c.any_education]) (_b[c.treatment#c.ethn00_30]/_se[c.treatment#c.ethn00_30]) (_b[c.treatment#c.little_land_]/_se[c.treatment#c.little_land_]) (_b[c.treatment#c.femalehead_]/_se[c.treatment#c.femalehead_])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress elite_new c.treatment##c.(age_ any_education ethn00_30 little_land_ femalehead_ ) i.enum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003 if regsample, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.age_  c.treatment#c.any_education  c.treatment#c.ethn00_30  c.treatment#c.little_land_  c.treatment#c.femalehead_  //name p-values so that esttab knows to which coefficient they belong
regress elite_new c.treatment##c.(age_ any_education ethn00_30 little_land_ femalehead_ ) i.enum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003 if regsample, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum elite_new if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[c.treatment#c.age_]/_se[c.treatment#c.age_]) (_b[c.treatment#c.any_education]/_se[c.treatment#c.any_education]) (_b[c.treatment#c.ethn00_30]/_se[c.treatment#c.ethn00_30]) (_b[c.treatment#c.little_land_]/_se[c.treatment#c.little_land_]) (_b[c.treatment#c.femalehead_]/_se[c.treatment#c.femalehead_])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress elite_new C.treatment#c.(age_ any_education ethn00_30 little_land_ femalehead_) c.(age_ ethn00_30 femalehead_ any_education little_land_ ) i.enum i.ethnicity i.village if regsample, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = c.treatment#c.age_  c.treatment#c.any_education  c.treatment#c.ethn00_30  c.treatment#c.little_land_  c.treatment#c.femalehead_  //name p-values so that esttab knows to which coefficient they belong
regress elite_new C.treatment#c.(age_ any_education ethn00_30 little_land_ femalehead_) c.(age_ ethn00_30 femalehead_ any_education little_land_ ) i.enum i.ethnicity i.village if regsample, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum elite_new if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
regress elite_new c.(elite_new_RF) if treatment, cluster(village) 
estimates store e3 
sum elite_new if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
* Output to file *
******************
esttab e* using "replication-supplement_table1", indicate("controls = logpop Noelec PublicWC NotImprovWat illiteracy logvnodes _cons" "village FX = *.village" " ward FX= *.ward_2003" " Ethnicity FX= *.ethnicity" " enumerator FX=*.*enum" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop(_cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N   , fmt(3 0 0 2 ) label("(control) mean d.v." N   ))
