/****************************************
Replication do-file for: Supplement Table 13A
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/households.dta", clear
regress ben_from_cddp_avg c.(marginalized elite_old elite_new) formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003 if treatment, cluster(village) 
estimates store e1 
sum ben_from_cddp_avg if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
regress ben_from_cddp_avg c.(little_land c.elite_old elite_new c.marginalized) formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003 if treatment, cluster(village) 
estimates store e2 
sum ben_from_cddp_avg if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
regress ben_from_noncddp_avg c.little_land c.elite_old elite_new c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003 if !treatment, cluster(village) 
estimates store e3 
sum ben_from_noncddp_avg if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
* Output to file *
******************
esttab e* using "replication-supplement_table13a", indicate("controls=formal_educ ethn00_30 *proxy hhsize _cons logpop Noelec PublicWC NotImprovWat illiteracy logvnodes" "ward FX= *.ward_2003" "Ethnicity FX= *.ethnicity" "enumerator FX=*.*enum" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop(_cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N   , fmt(3 0 0 2 ) label("(control) mean d.v." N   ))
