/****************************************
Replication do-file for: Supplementary Table 13, Panel B, Supplementary Table 14, Supplementary Table 15 , Supplementary Table 19
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files


est clear


use "data/projects.dta", clear
eststo failsummary3: estpost summarize ///
	failed_w_cdd_treat   ///
	failed_VS_cdd_treat  ///
	failed_enum_cdd_treat   
esttab failsummary3 using "replication-supplement_table15", cells(`"mean(fmt(0) par("" %) label(failure rate)) count(label(matched project groups) fmt(0))"') noobs  label  nodepvars  nomtitles nonum nodep varlabels(, end("" "") nolast) replace 

//drop if observations comes from focus group or enumerator report, remaining analyis is based on household reports
keep if indepth_household

est clear

estpost tab relative_ben_string  pclass , nototal
esttab .  using "replication-supplement_table14",  collabels(none)  noobs nonumber nomtitle  nonotes   cells(colpct(fmt(1) par("" %)))    unstack     ///
	posthead(Rel. benefit from project:) replace order( less same more)


eststo m2_1j: reghdfe village_dec 2.pclass 2.pclass#c.(marginalized  elite_old elite_new  little_land)  if treatment [pweight=projectweight]  , cluster(village) a(hha)
	sum `e(depvar)' if e(sample) & pclass!=2 [aweight`e(wexp)']
	estadd scalar ymeanc = r(mean)

	
eststo m2_2j: reghdfe oe_dec 2.pclass 2.pclass#c.(marginalized elite_new elite_old   little_land)  if treatment  [pweight=projectweight] , cluster(village) a(hha)
	sum `e(depvar)' if e(sample) & pclass!=2 [aweight`e(wexp)']
	estadd scalar ymeanc = r(mean)

	
eststo m2_3j: reghdfe vdc_dec 2.pclass 2.pclass#c.(marginalized elite_new elite_old   little_land)  if treatment  [pweight=projectweight] , cluster(village) a(hha)
	sum `e(depvar)' if e(sample) & pclass!=2 [aweight`e(wexp)']
	estadd scalar ymeanc = r(mean)

	
	
esttab m2_1j 	 m2_2j m2_3j  using "replication-supplement_table13b", mgroups( "Who decided on this pr.?",  pattern(1 0 0 ) )  ///
										drop(_cons, relax)		 replace 		  b(3) p(3) collabels(none)	label	 starlevels(* 0.1 ** 0.05 *** 0.01) 								///
										stats(N_full ymeanc , label("proj. reports" "mean d. v. (non-CDD)")) // 
										
	
	
est clear
foreach var of varlist 	village_dec vdc_dec oe_dec  voted {
	eststo hetf`var': reg `var' c.cddp##c.(marginalized elite_old) i.ward_2003 formal_educ    ethn00_30    iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=projectweight] , cluster(village) 
	estadd local rest = "all projects"	
	eststo spill`var': reg `var' c.treatment formal_educ    ethn00_30    iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003 [pweight=projectweight_type] if cddp==0, cluster(village)
	estadd local rest = "non-CDD"
}	
estadd ysumm: *


esttab  spill*  hetf*	 using "replication-supplement_table19", mgroups("Comparing non-CDD projects across villages" "Comparing CDD to non-CDD"  ,pattern(1 0 0 0 1 0 0 0 ) ) ///
										drop(_cons, relax)		 replace 		  b(3) p(3) collabels(none)	label	 starlevels(* 0.1 ** 0.05 *** 0.01) 			///
										indicate("controls =*.ethnicity *.ienum *.ward_2003 formal_educ    ethn00_30    iproxy hhsize *.ienum *.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes" ) stats(N rest ymean yrange , fmt(0 . 1 .)  labels("project reports" "sample" "mean dep. var." "dep. var. range"))

			
			