/****************************************
Replication do-file for: Supplement Table 2
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/dyads.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress m1_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress m1_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum m1_link if e(sample) & treatment==0 [aweight= dyad_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress m2_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress m2_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum m2_link if e(sample) & treatment==0 [aweight= dyad_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress m3_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress m3_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum m3_link if e(sample) & treatment==0 [aweight= dyad_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress m4_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress m4_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum m4_link if e(sample) & treatment==0 [aweight= dyad_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress m6_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress m6_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum m6_link if e(sample) & treatment==0 [aweight= dyad_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress m7_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress m7_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize dyad_enum* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.i_ethnicity i.j_ethnicity i.ward_2003 [pweight=dyad_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e6 
estadd matrix RI_p = RI_p
sum m7_link if e(sample) & treatment==0 [aweight= dyad_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
* Output to file *
******************
esttab e* using replication-supplement_table2, indicate("controls = any_marginalized any_elite_old dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup logpop Noelec PublicWC NotImprovWat illiteracy logvnodes" "ward FX=*ward_20*" "HH controls= *j_ethnic* *i_ethnic* ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize " "enumerator FX =dyad_enum*" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop( _cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N households  , fmt(3 0 0 2 ) label("(control) mean d.v." N households  ))
