/****************************************
Replication do-file for: Supplement Table 20Panelb
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/households.dta", clear
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress goandspeak c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.marginalized  //name p-values so that esttab knows to which coefficient they belong
regress goandspeak c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum goandspeak if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress numbermeetings c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.marginalized  //name p-values so that esttab knows to which coefficient they belong
regress numbermeetings c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum numbermeetings if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress decidebyvote99 c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.marginalized  //name p-values so that esttab knows to which coefficient they belong
regress decidebyvote99 c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum decidebyvote99 if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress actualvoting c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.marginalized  //name p-values so that esttab knows to which coefficient they belong
regress actualvoting c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum actualvoting if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress speakup c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.marginalized  //name p-values so that esttab knows to which coefficient they belong
regress speakup c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum speakup if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress change c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.marginalized  //name p-values so that esttab knows to which coefficient they belong
regress change c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e6 
estadd matrix RI_p = RI_p
sum change if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress speakalkalo c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.marginalized  //name p-values so that esttab knows to which coefficient they belong
regress speakalkalo c.treatment##c.marginalized formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e7 
estadd matrix RI_p = RI_p
sum speakalkalo if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
* Output to file *
******************
esttab e* using "replication-supplement_table20panelB", indicate("controls = logpop Noelec PublicWC NotImprovWat illiteracy logvnodes formal_educ ethn00_30 *proxy hhsize _cons" "ward FX= *.ward_2003" "Ethnicity FX= *.ethnicity" "enumerator FX=*.*enum" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop(_cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N   , fmt(3 0 0 2 ) label("(control) mean d.v." N   ))
