/****************************************
Replication do-file for: Supplement Table 3
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/villages.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress new_density_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress new_density_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum new_density_eco if e(sample) & treatment==0 [aweight= vill_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress new_avg_ipl_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress new_avg_ipl_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum new_avg_ipl_eco if e(sample) & treatment==0 [aweight= vill_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress new_undir_clu_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress new_undir_clu_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum new_undir_clu_eco if e(sample) & treatment==0 [aweight= vill_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress new_trianglecount_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress new_trianglecount_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum new_trianglecount_eco if e(sample) & treatment==0 [aweight= vill_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress new_support_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress new_support_eco treatment enum_du* ethn_du* i.ward_2003 logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=vill_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum new_support_eco if e(sample) & treatment==0 [aweight= vill_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)

******************
* Output to file *
******************
esttab e* using "replication-supplement_table3", indicate("ward FX = *.ward_2003" "controls = logpop Noelec PublicWC NotImprovWat illiteracy logvnodes enum_du* ethn_du*" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop(_cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N   , fmt(3 0 0 2 ) label("(control) mean d.v." N   ))
