/****************************************
Replication do-file for: Supplement Table 6A
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/diddyads.dta", clear
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.wave]/_se[c.treatment#c.wave])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress eco_link c.treatment##c.wave logpop Noelec PublicWC NotImprovWat illiteracy logvnodes any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize diff_formal_educ diff_ethn00_30 diff_hhsize i.ward_2003 if 1 [pweight=weights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.wave  //name p-values so that esttab knows to which coefficient they belong
regress eco_link c.treatment##c.wave logpop Noelec PublicWC NotImprovWat illiteracy logvnodes any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize diff_formal_educ diff_ethn00_30 diff_hhsize i.ward_2003 if 1 [pweight=weights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum eco_link if e(sample) & treatment==0 [aweight= weights] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[c.treatment#c.wave]/_se[c.treatment#c.wave])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress eco_link c.treatment#c.wave i.village wave any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize diff_formal_educ diff_ethn00_30 diff_hhsize if 1 [pweight=weights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = c.treatment#c.wave  //name p-values so that esttab knows to which coefficient they belong
regress eco_link c.treatment#c.wave i.village wave any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize diff_formal_educ diff_ethn00_30 diff_hhsize if 1 [pweight=weights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum eco_link if e(sample) & treatment==0 [aweight= weights] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.wave]/_se[c.treatment#c.wave])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress eco_link_undirected c.treatment##c.wave logpop Noelec PublicWC NotImprovWat illiteracy logvnodes any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize adiff_formal_educ adiff_ethn00_30 adiff_hhsize i.ward_2003 if dyadobs==1 [pweight=weights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.wave  //name p-values so that esttab knows to which coefficient they belong
regress eco_link_undirected c.treatment##c.wave logpop Noelec PublicWC NotImprovWat illiteracy logvnodes any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize adiff_formal_educ adiff_ethn00_30 adiff_hhsize i.ward_2003 if dyadobs==1 [pweight=weights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum eco_link_undirected if e(sample) & treatment==0 [aweight= weights] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[c.treatment#c.wave]/_se[c.treatment#c.wave])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress eco_link_undirected c.treatment#c.wave i.village wave any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize adiff_formal_educ adiff_ethn00_30 adiff_hhsize if dyadobs==1 [pweight=weights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = c.treatment#c.wave  //name p-values so that esttab knows to which coefficient they belong
regress eco_link_undirected c.treatment#c.wave i.village wave any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize adiff_formal_educ adiff_ethn00_30 adiff_hhsize if dyadobs==1 [pweight=weights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum eco_link_undirected if e(sample) & treatment==0 [aweight= weights] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.wave]/_se[c.treatment#c.wave])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress fam_link_undirected c.treatment##c.wave logpop Noelec PublicWC NotImprovWat illiteracy logvnodes any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize adiff_formal_educ adiff_ethn00_30 adiff_hhsize i.ward_2003 if dyadobs==1 [pweight=weights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.wave  //name p-values so that esttab knows to which coefficient they belong
regress fam_link_undirected c.treatment##c.wave logpop Noelec PublicWC NotImprovWat illiteracy logvnodes any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize adiff_formal_educ adiff_ethn00_30 adiff_hhsize i.ward_2003 if dyadobs==1 [pweight=weights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum fam_link_undirected if e(sample) & treatment==0 [aweight= weights] //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[c.treatment#c.wave]/_se[c.treatment#c.wave])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress fam_link_undirected c.treatment#c.wave i.village wave any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize adiff_formal_educ adiff_ethn00_30 adiff_hhsize if dyadobs==1 [pweight=weights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = c.treatment#c.wave  //name p-values so that esttab knows to which coefficient they belong
regress fam_link_undirected c.treatment#c.wave i.village wave any_elite_old any_marginalized dyad_shared_ethn dyad_shared_interviewgroup dyad_enum* dyad_ethnicity* sum_formal_educ sum_ethn00_30 sum_hhsize adiff_formal_educ adiff_ethn00_30 adiff_hhsize if dyadobs==1 [pweight=weights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e6 
estadd matrix RI_p = RI_p
sum fam_link_undirected if e(sample) & treatment==0 [aweight= weights] //adding the control mean
estadd scalar ymean = r(mean)

******************
* Output to file *
******************
esttab e* using replication-supplement_table6a, indicate( "controls= any_elite_old any_marginalized  dyad_shared_ethn dyad_shared_interviewgroup  dyad_enum* dyad_ethnicity*  sum_formal_educ sum_ethn00_30 sum_hhsize diff_formal_educ diff_ethn00_30 diff_hhsize adiff_* logpop Noelec PublicWC NotImprovWat illiteracy logvnodes *.ward_2003" "village FX=*.village" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop( _cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N   , fmt(3 0 0 2 ) label("(control) mean d.v." N   ))
