/****************************************
Replication do-file for: Supplementary Table 7
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

est clear

use "data/villages.dta", clear

reshape long number imputed_costsT confirmednumber confirmedimputed_costsT, i(village ward_2003) j(year)
label var number "projects"
label var confirmednumber "projects"
label var imputed_costsT  "project budget"
label var confirmedimputed_costsT "project budget"
gen implementation = year>=2008 & year<=2010
label var implementation "CDD years (2008-2010)"
gen post = year>=2011 
label var post  "post CDD years (2011-2014)"
	
eststo, prefix(twnumber): reg number  c.treatment##c.(implementation post) i.ward_2003 ,   nocons cluster(village)
	sum `e(depvar)' if e(sample) & treatment==0
	estadd scalar ymean = r(mean)

eststo, prefix(twimputed_costsT): reg imputed_costsT  c.treatment##c.(implementation post) i.ward_2003  ,   nocons cluster(village)
	sum `e(depvar)' if e(sample) & treatment==0
	estadd scalar ymean = r(mean)

eststo, prefix(twconfirmednumber): reg confirmednumber c.treatment##c.(implementation post) i.ward_2003 ,   nocons cluster(village)
	sum `e(depvar)' if e(sample) & treatment==0
	estadd scalar ymean = r(mean)

eststo, prefix(twconfirmedimputed_costsT): reg confirmedimputed_costsT  c.treatment##c.(implementation post) i.ward_2003  ,   nocons cluster(village)
	sum `e(depvar)' if e(sample) & treatment==0
	estadd scalar ymean = r(mean)


esttab * using replication-supplement_table7, replace stats(N ymean, label(N )) starlevels(* 0.1 ** 0.05 *** 0.01) b p   indicate( "ward FX=*.ward_2003")  ///
	nonotes  label mgroups("projects listed by village focus group" "projects listed by at least 3 respondents", pattern(1 0 1 0 0) ) /// 
	order(treatment implementation *treatment*implementation*  post *treatment*post*)
				