/****************************************
Replication do-file for: Table 2
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/dyads.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress m5_link_undirected c.treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* dyad_ethnicity* sum_formal_educ adiff_formal_educ sum_ethn00_30 adiff_ethn00_30 sum_proxy adiff_proxy sum_hhsize adiff_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes if dyadobs==1 [pweight=helpweights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress m5_link_undirected c.treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* dyad_ethnicity* sum_formal_educ adiff_formal_educ sum_ethn00_30 adiff_ethn00_30 sum_proxy adiff_proxy sum_hhsize adiff_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes if dyadobs==1 [pweight=helpweights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum m5_link_undirected if e(sample) & treatment==0 [aweight= helpweights] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress mIS7_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* i.i_ethnicity i.j_ethnicity ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes bothIS if j_IS_hh==1 | i_IS_hh==1 [pweight=helpweights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress mIS7_link treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* i.i_ethnicity i.j_ethnicity ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes bothIS if j_IS_hh==1 | i_IS_hh==1 [pweight=helpweights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum mIS7_link if e(sample) & treatment==0 [aweight= helpweights] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.any_marginalized]/_se[c.treatment#c.any_marginalized]) (_b[c.treatment#c.any_elite_old]/_se[c.treatment#c.any_elite_old]) (_b[c.treatment#c.any_elite_new_RF_s]/_se[c.treatment#c.any_elite_new_RF_s])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress m5_link_undirected c.treatment any_marginalized any_elite_old any_elite_new_RF_s c.treatment#c.(any_marginalized any_elite_old any_elite_new_RF_s) dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* dyad_ethnicity* sum_formal_educ adiff_formal_educ sum_ethn00_30 adiff_ethn00_30 sum_proxy adiff_proxy sum_hhsize adiff_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes if dyadobs==1 [pweight=helpweights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.any_marginalized  c.treatment#c.any_elite_old  c.treatment#c.any_elite_new_RF_s  //name p-values so that esttab knows to which coefficient they belong
regress m5_link_undirected c.treatment any_marginalized any_elite_old any_elite_new_RF_s c.treatment#c.(any_marginalized any_elite_old any_elite_new_RF_s) dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* dyad_ethnicity* sum_formal_educ adiff_formal_educ sum_ethn00_30 adiff_ethn00_30 sum_proxy adiff_proxy sum_hhsize adiff_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes if dyadobs==1 [pweight=helpweights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum m5_link_undirected if e(sample) & treatment==0 [aweight= helpweights] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.any_elite_old]/_se[c.treatment#c.any_elite_old]) (_b[c.treatment#c.any_marginalized]/_se[c.treatment#c.any_marginalized]) (_b[c.treatment#c.any_elite_new_RF_s]/_se[c.treatment#c.any_elite_new_RF_s])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress mIS7_link c.treatment##c.(any_elite_old any_marginalized any_elite_new_RF_s) dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup dyad_enum* i.i_ethnicity i.j_ethnicity ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003 bothIS if j_IS_hh==1 | i_IS_hh==1 [pweight=helpweights], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.any_elite_old  c.treatment#c.any_marginalized  c.treatment#c.any_elite_new_RF_s  //name p-values so that esttab knows to which coefficient they belong
regress mIS7_link c.treatment##c.(any_elite_old any_marginalized any_elite_new_RF_s) dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup dyad_enum* i.i_ethnicity i.j_ethnicity ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes i.ward_2003 bothIS if j_IS_hh==1 | i_IS_hh==1 [pweight=helpweights], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum mIS7_link if e(sample) & treatment==0 [aweight= helpweights] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
use "data/households.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress numbermeetings treatment elite_old marginalized i.ward_2003 formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress numbermeetings treatment elite_old marginalized i.ward_2003 formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum numbermeetings if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress groups treatment elite_old marginalized i.ward_2003 formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress groups treatment elite_old marginalized i.ward_2003 formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e6 
estadd matrix RI_p = RI_p
sum groups if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.elite_old]/_se[c.treatment#c.elite_old]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized]) (_b[c.treatment#c.elite_new_RF_s]/_se[c.treatment#c.elite_new_RF_s])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress numbermeetings c.treatment##c.(elite_old marginalized elite_new_RF_s) i.ward_2003 formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.elite_old  c.treatment#c.marginalized  c.treatment#c.elite_new_RF_s  //name p-values so that esttab knows to which coefficient they belong
regress numbermeetings c.treatment##c.(elite_old marginalized elite_new_RF_s) i.ward_2003 formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e7 
estadd matrix RI_p = RI_p
sum numbermeetings if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.elite_old]/_se[c.treatment#c.elite_old]) (_b[c.treatment#c.marginalized]/_se[c.treatment#c.marginalized]) (_b[c.treatment#c.elite_new_RF_s]/_se[c.treatment#c.elite_new_RF_s])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress groups c.treatment##c.(elite_old marginalized elite_new_RF_s) i.ward_2003 formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.elite_old  c.treatment#c.marginalized  c.treatment#c.elite_new_RF_s  //name p-values so that esttab knows to which coefficient they belong
regress groups c.treatment##c.(elite_old marginalized elite_new_RF_s) i.ward_2003 formal_educ ethn00_30 iproxy hhsize i.ienum i.ethnicity logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e8 
estadd matrix RI_p = RI_p
sum groups if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
* Output to file *
******************
//different data were used for different regressions, we just append them to get the var labels right.
append using  "data/dyads.dta"
esttab e* using replication-table2, indicate("controls =dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup logpop Noelec PublicWC NotImprovWat illiteracy logvnodes formal_educ ethn00_30 iproxy hhsize bothIS" "ward FX=*ward_20*" "HH controls=*j_ethnic* *i_ethnic* dyad_ethnicity* *.ethnicity sum_formal_educ adiff_formal_educ sum_ethn00_30 adiff_ethn00_30 sum_proxy adiff_proxy sum_hhsize adiff_hhsize ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize " "enumerator FX =dyad_enum* *.ienum" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop( _cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N households  , fmt(3 0 0 2 ) label("(control) mean d.v." N households  ))
