/****************************************
Replication do-file for: Table 4
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/census.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress zscore_animals treatment i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress zscore_animals treatment i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum zscore_animals if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.c_education]/_se[c.treatment#c.c_education]) (_b[c.treatment#c.c_meanbornheregrown]/_se[c.treatment#c.c_meanbornheregrown]) (_b[c.treatment#c.c_hhsize]/_se[c.treatment#c.c_hhsize])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress zscore_animals treatment c.treatment#c.(c_education c_meanbornheregrown c_hhsize) c_meanbornheregrown i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.c_education  c.treatment#c.c_meanbornheregrown  c.treatment#c.c_hhsize  //name p-values so that esttab knows to which coefficient they belong
regress zscore_animals treatment c.treatment#c.(c_education c_meanbornheregrown c_hhsize) c_meanbornheregrown i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum zscore_animals if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.s_RF_predicted_outcome]/_se[c.treatment#c.s_RF_predicted_outcome])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress zscore_animals c.treatment##c.(s_RF_predicted_outcome) i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.s_RF_predicted_outcome  //name p-values so that esttab knows to which coefficient they belong
regress zscore_animals c.treatment##c.(s_RF_predicted_outcome) i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum zscore_animals if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress zscore_assets treatment i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress zscore_assets treatment i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum zscore_assets if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.c_education]/_se[c.treatment#c.c_education]) (_b[c.treatment#c.c_meanbornheregrown]/_se[c.treatment#c.c_meanbornheregrown]) (_b[c.treatment#c.c_hhsize]/_se[c.treatment#c.c_hhsize])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress zscore_assets treatment c.treatment#c.(c_education c_meanbornheregrown c_hhsize) c_meanbornheregrown i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.c_education  c.treatment#c.c_meanbornheregrown  c.treatment#c.c_hhsize  //name p-values so that esttab knows to which coefficient they belong
regress zscore_assets treatment c.treatment#c.(c_education c_meanbornheregrown c_hhsize) c_meanbornheregrown i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum zscore_assets if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.s_RF_predicted_outcome]/_se[c.treatment#c.s_RF_predicted_outcome])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress zscore_assets c.treatment##c.(s_RF_predicted_outcome) i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.s_RF_predicted_outcome  //name p-values so that esttab knows to which coefficient they belong
regress zscore_assets c.treatment##c.(s_RF_predicted_outcome) i.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new i.ward_2003, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e6 
estadd matrix RI_p = RI_p
sum zscore_assets if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
* Output to file *
******************
esttab e* using "replication-table4", indicate("ward FX = *.ward_2003" "controls =*.ethnicity hhsize education ethn00_30 logpop illiteracy_new PublicWC_new Noelec_new NotImprovWat_new s_RF_predicted_outcome c_meanbornheregrown", ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop(_cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N   , fmt(3 0 0 2 ) label("(control) mean d.v." N   ))
