/****************************************
Replication do-file for: Table 5
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/households.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress textdeg_in_m123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress textdeg_in_m123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum textdeg_in_m123467 if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress textdeg_in_mu123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress textdeg_in_mu123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum textdeg_in_mu123467 if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress tpayextdeg_in_m123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress tpayextdeg_in_m123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum tpayextdeg_in_m123467 if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress textdeg_out_m123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress textdeg_out_m123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum textdeg_out_m123467 if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress textdeg_out_mu123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress textdeg_out_mu123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum textdeg_out_mu123467 if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress tpayextdeg_out_m123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress tpayextdeg_out_m123467 treatment i.ward_2003 formal_educ ethn00_30 proxy hhsize i.enum i.ethnicity elite_old marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes, cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e6 
estadd matrix RI_p = RI_p
sum tpayextdeg_out_m123467 if e(sample) & treatment==0 //adding the control mean
estadd scalar ymean = r(mean)

******************
* Output to file *
******************
esttab e* using "replication-table5", indicate("controls = logpop Noelec PublicWC NotImprovWat illiteracy logvnodes formal_educ ethn00_30 proxy hhsize elite_old marginalized _cons" "ward FX= *.ward_2003" "Ethnicity FX= *.ethnicity" "enumerator FX=*.*enum" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop(_cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N   , fmt(3 0 0 2 ) label("(control) mean d.v." N   ))
