/****************************************
Replication do-file for: Table 6
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/dyads.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress eco_recipp_link_undirected c.treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* dyad_ethnicity* sum_formal_educ adiff_formal_educ sum_ethn00_30 adiff_ethn00_30 sum_proxy adiff_proxy sum_hhsize adiff_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes if dyadobs==1 [pweight=dyad_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
regress eco_recipp_link_undirected c.treatment any_elite_old any_marginalized dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* dyad_ethnicity* sum_formal_educ adiff_formal_educ sum_ethn00_30 adiff_ethn00_30 sum_proxy adiff_proxy sum_hhsize adiff_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes if dyadobs==1 [pweight=dyad_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum eco_recipp_link_undirected if e(sample) & treatment==0 [aweight= dyad_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
ritest treatment (_b[treatment]/_se[treatment]) (_b[c.treatment#c.common_nodes_geo_fam_ce]/_se[c.treatment#c.common_nodes_geo_fam_ce])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	regress eco_link c.treatment any_elite_old any_marginalized common_nodes_geo_fam_ce c.treatment#c.common_nodes_geo_fam_ce distance_rank geomiss dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* i.i_ethnicity i.j_ethnicity ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=dyad_weights_hhs], cluster(village) 
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  c.treatment#c.common_nodes_geo_fam_ce  //name p-values so that esttab knows to which coefficient they belong
regress eco_link c.treatment any_elite_old any_marginalized common_nodes_geo_fam_ce c.treatment#c.common_nodes_geo_fam_ce distance_rank geomiss dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup i.ward_2003 dyad_enum* i.i_ethnicity i.j_ethnicity ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize logpop Noelec PublicWC NotImprovWat illiteracy logvnodes [pweight=dyad_weights_hhs], cluster(village)  //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum eco_link if e(sample) & treatment==0 [aweight= dyad_weights_hhs] //adding the control mean
estadd scalar ymean = r(mean)
qui unique Source if e(sample) //count number of distinct households estimation sample
qui estadd scalar households = `r(unique)', replace

******************
* Output to file *
******************
esttab e* using replication-table6, indicate("controls =dyad_shared_ethn dyad_kinship_undirected dyad_shared_interviewgroup any_elite_old any_marginalized logpop Noelec PublicWC NotImprovWat illiteracy logvnodes" "ward FX=*ward_20*" "HH controls=*j_ethnic* *i_ethnic* dyad_ethnicity* ?_formal_educ ?_ethn00_30 ?_proxy ?_hhsize sum_formal_educ adiff_formal_educ sum_ethn00_30 adiff_ethn00_30 sum_proxy adiff_proxy sum_hhsize adiff_hhsize distance_rank geomiss" "enumerator FX =dyad_enum*" , ) label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop( _cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) noomitted stats(ymean N households  , fmt(3 0 0 2 ) label("(control) mean d.v." N households  ))
