/****************************************
Replication do-file for: Table A1
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/census03.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg female treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg female treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum female if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum female if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg age treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg age treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum age if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum age if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg wealth3_ele treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg wealth3_ele treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum wealth3_ele if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum wealth3_ele if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg wealth4_wat treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg wealth4_wat treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum wealth4_wat if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum wealth4_wat if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg wealth2_toi treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg wealth2_toi treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum wealth2_toi if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum wealth2_toi if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg wealth1_lit treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg wealth1_lit treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e6 
estadd matrix RI_p = RI_p
sum wealth1_lit if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum wealth1_lit if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg mandinka treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg mandinka treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e7 
estadd matrix RI_p = RI_p
sum mandinka if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum mandinka if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg moved_here_5y treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg moved_here_5y treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e8 
estadd matrix RI_p = RI_p
sum moved_here_5y if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum moved_here_5y if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg education treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg education treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e9 
estadd matrix RI_p = RI_p
sum education if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum education if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
use "data/villages.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg elec_percent treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg elec_percent treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e10 
estadd matrix RI_p = RI_p
sum elec_percent if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum elec_percent if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg WC_percent treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg WC_percent treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e11 
estadd matrix RI_p = RI_p
sum WC_percent if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum WC_percent if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg water_percent treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg water_percent treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e12 
estadd matrix RI_p = RI_p
sum water_percent if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum water_percent if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg literate_percent treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg literate_percent treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e13 
estadd matrix RI_p = RI_p
sum literate_percent if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum literate_percent if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg pop_new treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg pop_new treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e14 
estadd matrix RI_p = RI_p
sum pop_new if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum pop_new if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg vnodes treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg vnodes treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e15 
estadd matrix RI_p = RI_p
sum vnodes if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum vnodes if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
use "data/households.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg elite_old treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg elite_old treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e16 
estadd matrix RI_p = RI_p
sum elite_old if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum elite_old if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg marginalized treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg marginalized treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e17 
estadd matrix RI_p = RI_p
sum marginalized if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum marginalized if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg formal_educ treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg formal_educ treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e18 
estadd matrix RI_p = RI_p
sum formal_educ if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum formal_educ if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg ethn00_30 treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg ethn00_30 treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e19 
estadd matrix RI_p = RI_p
sum ethn00_30 if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum ethn00_30 if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg proxy treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg proxy treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e20 
estadd matrix RI_p = RI_p
sum proxy if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum proxy if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg hhsize treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg hhsize treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e21 
estadd matrix RI_p = RI_p
sum hhsize if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum hhsize if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
use "data/census03.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg bornhere treatment if head==1, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg bornhere treatment if head==1, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e22 
estadd matrix RI_p = RI_p
sum bornhere if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum bornhere if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg compoundsize treatment if head==1, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg compoundsize treatment if head==1, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e23 
estadd matrix RI_p = RI_p
sum compoundsize if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum compoundsize if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg coethnics treatment if head==1, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg coethnics treatment if head==1, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e24 
estadd matrix RI_p = RI_p
sum coethnics if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum coethnics if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg spouse_bornhere treatment if head==1, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg spouse_bornhere treatment if head==1, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e25 
estadd matrix RI_p = RI_p
sum spouse_bornhere if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum spouse_bornhere if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
* Output to file *
******************
//different data were used for different regressions, we just append them to get the var labels right.
append using  "data/census03.dta"
append using  "data/villages.dta"
append using  "data/households.dta"
esttab e* using "replication-tableA1", label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop(_cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) stats(Nt Nc ymeant ymeanc raw_diff, fmt(0 0 2 2 3)  label("obs. (treatment)" "obs. (control)" "mean d.v. (treatment)" "mean d.v. (control)" "raw difference"))
