/****************************************
Replication do-file for: Table A2
Paper:                   Heß, Schündeln, Jaimovich: Development Projects and Economic Networks: Lessons From Rural Gambia
Journal:                 Review of Economic Studies
Contact:                 Simon Heß (hess@econ.uni-frankfurt.de)
****************************************/

/************  Dependencies ***************/
//To install required Stata packages from SSC, please run the master do files (replicate main tables.do or replicate online supplementary tables.do)
//To load required routines, please run rerandomize.ado or run the master do-files

/************  Settings  ***************/
global ritest_R=cond(0$ritest_R , 0$ritest_R , 100) // use 100 re-randomizations for randomization inference, unless global ritest_R is set to a different value

est clear

******************
use "data/households.dta", clear
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg degree_undir_eco treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg degree_undir_eco treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e1 
estadd matrix RI_p = RI_p
sum degree_undir_eco if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum degree_undir_eco if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg intdeg_undir_m1 treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg intdeg_undir_m1 treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e2 
estadd matrix RI_p = RI_p
sum intdeg_undir_m1 if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum intdeg_undir_m1 if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg intdeg_undir_m2 treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg intdeg_undir_m2 treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e3 
estadd matrix RI_p = RI_p
sum intdeg_undir_m2 if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum intdeg_undir_m2 if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg intdeg_undir_m3 treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg intdeg_undir_m3 treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e4 
estadd matrix RI_p = RI_p
sum intdeg_undir_m3 if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum intdeg_undir_m3 if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg intdeg_undir_m4 treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg intdeg_undir_m4 treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e5 
estadd matrix RI_p = RI_p
sum intdeg_undir_m4 if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum intdeg_undir_m4 if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg intdeg_undir_m6 treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg intdeg_undir_m6 treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e6 
estadd matrix RI_p = RI_p
sum intdeg_undir_m6 if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum intdeg_undir_m6 if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg intdeg_undir_m7 treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg intdeg_undir_m7 treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e7 
estadd matrix RI_p = RI_p
sum intdeg_undir_m7 if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum intdeg_undir_m7 if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg intdeg_undir_m5 treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg intdeg_undir_m5 treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e8 
estadd matrix RI_p = RI_p
sum intdeg_undir_m5 if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum intdeg_undir_m5 if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg intdeg_undir_m8a8b8c treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg intdeg_undir_m8a8b8c treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e9 
estadd matrix RI_p = RI_p
sum intdeg_undir_m8a8b8c if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum intdeg_undir_m8a8b8c if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg meangeodist treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg meangeodist treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e10 
estadd matrix RI_p = RI_p
sum meangeodist if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum meangeodist if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg hh_geomiss treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg hh_geomiss treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e11 
estadd matrix RI_p = RI_p
sum hh_geomiss if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum hh_geomiss if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
ritest treatment (_b[treatment]/_se[treatment])  , seed(2020) randomizationprogram(rerandomize) randomizationprogramoptions("stratvar(ward_2003) clustvar(village)") rep($ritest_R) force: ///
	areg hh_neighbours treatment, cluster(village) a(ward_2003)
matrix RI_p=r(p) //save  p-values from ritest 
mat colnames RI_p = treatment  //name p-values so that esttab knows to which coefficient they belong
areg hh_neighbours treatment, cluster(village) a(ward_2003) //execute the command again, becaus we need e(sample)
estimates store e12 
estadd matrix RI_p = RI_p
sum hh_neighbours if e(sample) &  treatment==0 //adding the control mean
estadd scalar ymeanc = r(mean)
estadd scalar Nc = r(N)
sum hh_neighbours if e(sample) &  treatment==1 //adding the control mean
estadd scalar ymeant = r(mean)
estadd scalar Nt = r(N)
estadd scalar raw_diff = e(ymeant)-e(ymeanc)

******************
* Output to file *
******************
esttab e* using "replication-tableA2", label replace cells(b(fmt(3) star) p(fmt(3) par(( ))) RI_p(fmt(3) par([ ]))) drop(_cons,relax) starlevels(* 0.1 ** 0.05 *** 0.01)  modelwidth(20) varwidth(30) stats(Nt Nc ymeant ymeanc raw_diff, fmt(0 0 2 2 3)  label("obs. (treatment)" "obs. (control)" "mean d.v. (treatment)" "mean d.v. (control)" "raw difference"))
